[PATCH] D55581: Switch Android from TLS_SLOT_TSAN(8) to TLS_SLOT_SANITIZER(6)

Ryan Prichard via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Dec 12 14:49:41 PST 2018


This revision was automatically updated to reflect the committed changes.
Closed by commit rL348984: Switch Android from TLS_SLOT_TSAN(8) to TLS_SLOT_SANITIZER(6) (authored by rprichard, committed by ).

Repository:
  rL LLVM

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D55581/new/

https://reviews.llvm.org/D55581

Files:
  compiler-rt/trunk/lib/sanitizer_common/sanitizer_linux.h


Index: compiler-rt/trunk/lib/sanitizer_common/sanitizer_linux.h
===================================================================
--- compiler-rt/trunk/lib/sanitizer_common/sanitizer_linux.h
+++ compiler-rt/trunk/lib/sanitizer_common/sanitizer_linux.h
@@ -134,13 +134,13 @@
 #error "Unsupported architecture."
 #endif
 
-// The Android Bionic team has allocated a TLS slot for TSan starting with N,
-// given that Android currently doesn't support ELF TLS. It is used to store
-// Sanitizers thread specific data.
-static const int TLS_SLOT_TSAN = 8;
+// The Android Bionic team has allocated a TLS slot for sanitizers starting
+// with Q, given that Android currently doesn't support ELF TLS. It is used to
+// store sanitizer thread specific data.
+static const int TLS_SLOT_SANITIZER = 6;
 
 ALWAYS_INLINE uptr *get_android_tls_ptr() {
-  return reinterpret_cast<uptr *>(&__get_tls()[TLS_SLOT_TSAN]);
+  return reinterpret_cast<uptr *>(&__get_tls()[TLS_SLOT_SANITIZER]);
 }
 
 #endif  // SANITIZER_ANDROID


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D55581.177938.patch
Type: text/x-patch
Size: 1011 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20181212/0464ca44/attachment.bin>


More information about the llvm-commits mailing list